From 11eabb61b2a73a647a4bc0c67517cbaf6681e31c Mon Sep 17 00:00:00 2001
From: Amul Sul <amul.sul@enterprisedb.com>
Date: Wed, 14 Dec 2022 14:19:13 +0530
Subject: [PATCH v1 24/25] Change uuid_in to allow non-throw error reporting

---
 src/backend/utils/adt/uuid.c       |  8 ++++----
 src/test/regress/expected/uuid.out | 13 +++++++++++++
 src/test/regress/sql/uuid.sql      |  4 ++++
 3 files changed, 21 insertions(+), 4 deletions(-)

diff --git a/src/backend/utils/adt/uuid.c b/src/backend/utils/adt/uuid.c
index 7cec9372485..9adf20b896a 100644
--- a/src/backend/utils/adt/uuid.c
+++ b/src/backend/utils/adt/uuid.c
@@ -31,7 +31,7 @@ typedef struct
 	hyperLogLogState abbr_card; /* cardinality estimator */
 } uuid_sortsupport_state;
 
-static void string_to_uuid(const char *source, pg_uuid_t *uuid);
+static void string_to_uuid(const char *source, pg_uuid_t *uuid, Node *escontext);
 static int	uuid_internal_cmp(const pg_uuid_t *arg1, const pg_uuid_t *arg2);
 static int	uuid_fast_cmp(Datum x, Datum y, SortSupport ssup);
 static bool uuid_abbrev_abort(int memtupcount, SortSupport ssup);
@@ -44,7 +44,7 @@ uuid_in(PG_FUNCTION_ARGS)
 	pg_uuid_t  *uuid;
 
 	uuid = (pg_uuid_t *) palloc(sizeof(*uuid));
-	string_to_uuid(uuid_str, uuid);
+	string_to_uuid(uuid_str, uuid, fcinfo->context);
 	PG_RETURN_UUID_P(uuid);
 }
 
@@ -87,7 +87,7 @@ uuid_out(PG_FUNCTION_ARGS)
  * digits, is the only one used for output.)
  */
 static void
-string_to_uuid(const char *source, pg_uuid_t *uuid)
+string_to_uuid(const char *source, pg_uuid_t *uuid, Node *escontext)
 {
 	const char *src = source;
 	bool		braces = false;
@@ -130,7 +130,7 @@ string_to_uuid(const char *source, pg_uuid_t *uuid)
 	return;
 
 syntax_error:
-	ereport(ERROR,
+	ereturn(escontext, (void) 0,
 			(errcode(ERRCODE_INVALID_TEXT_REPRESENTATION),
 			 errmsg("invalid input syntax for type %s: \"%s\"",
 					"uuid", source)));
diff --git a/src/test/regress/expected/uuid.out b/src/test/regress/expected/uuid.out
index 090103df48a..cbf4f35a479 100644
--- a/src/test/regress/expected/uuid.out
+++ b/src/test/regress/expected/uuid.out
@@ -157,3 +157,16 @@ SELECT count(DISTINCT guid_field) FROM guid1;
 
 -- clean up
 DROP TABLE guid1, guid2 CASCADE;
+-- test non-error-throwing API for some core types
+SELECT pg_input_is_valid('11', 'uuid');
+ pg_input_is_valid 
+-------------------
+ f
+(1 row)
+
+SELECT pg_input_error_message('11', 'uuid');
+          pg_input_error_message          
+------------------------------------------
+ invalid input syntax for type uuid: "11"
+(1 row)
+
diff --git a/src/test/regress/sql/uuid.sql b/src/test/regress/sql/uuid.sql
index 3bd3b357c77..f82b4e97047 100644
--- a/src/test/regress/sql/uuid.sql
+++ b/src/test/regress/sql/uuid.sql
@@ -83,3 +83,7 @@ SELECT count(DISTINCT guid_field) FROM guid1;
 
 -- clean up
 DROP TABLE guid1, guid2 CASCADE;
+
+-- test non-error-throwing API for some core types
+SELECT pg_input_is_valid('11', 'uuid');
+SELECT pg_input_error_message('11', 'uuid');
-- 
2.18.0

